/*
	ds_adc.h	
	avr-gcc function prototype
	
	Delta Sigma Analog to Digital Converter
	Uros Platise (c) April 1999
	
	Version 1.2
*/

#ifndef __DS_ADC
#define __DS_ADC

/* Delta Sigma A/D converter must be initialized before it is used.
   The following function configures output pin and prepeares initial
   voltage of the capacitor Uc. This function might loop in worst
   case for about 10 ms.
*/
void ds_adc_init();


/* Perform A/D conversion. Acquistion time 10 ms. 
  
   Scale constant:
   	U_input = (U_cc * ds_adc()) >> 8;
*/
unsigned char ds_adc();


/* ADC Hard-Coded Configuration Macros 

   Note: ds_adc.o must be linked after the C module
         that use below macros.
	
  * Macro DS_ADC_SET_PORT sets I/O ports. Example:
  
  	DS_ADC_SET_PORT(2, 0x18); 
	
    To set PB2 and PORTB what is also the default.
  
  * Macro DS_ADC_SET_OFFSET is used to compensate constant
    error. Usually it equals 4.
  
  * Macro DS_ADC_SET_TIMEOUT sets time-out period that
    breaks the conversion if voltage out of range is applied
    to the input.
    
    
  Note: You must pass numbers to the following macros and not
        "other" macros unless target file with appropriate
	macro defintions is provided and at least ava version
	0.3 or higher is installed.
	
  C Example:
  
  int main(){
    unsigned char x;
    DS_ADC_SET_OFFSET(4);
    DS_ADC_SET_PORT(1, 0x18);
    ds_adc_init();    
    x = ds_adc();
  }
  
  asm example:
  
  #define public DS_ADC_OFFSET_VOLTAGE	4
*/

#define DS_ADC_SET_PORT(pin, port) \
	asm volatile("#define public DS_ADC_OUT_PIN " #pin "\n" \
	             "\t#define public DS_ADC_OUT_PORT " #port "\n")

#define DS_ADC_SET_OFFSET(offset_voltage) \
	asm volatile("#define public DS_ADC_OFFSET_VOLTAGE " \
		     #offset_voltage "\n")
		     
#define DS_ADC_SET_TIMEOUT(expire_period) \
	asm volatile("#define public DS_ADC_EXPIRE_PERIOD " \
		     #expire_period "\n")

#endif

