/*
	ds_adc.inc
	Assembler function prototype and help on 
	cofiguration public macros.
	
	Delta Sigma Analog to Digital Converter
	Uros Platise (c) April 1999
*/

#ifndef __ASM_DS_ADC
#define __ASM_DS_ADC

/* Delta Sigma A/D converter must be initialized before it is used.
   The following function configures output pin and prepeares initial
   voltage of the capacitor Uc. This function might loop in worst
   case for about 10 ms.
*/
extern _ds_adc_init


/* Perform A/D conversion. Acquistion time 10 ms. 
  
   Scale constant:
   	U_input = (U_cc * ds_adc()) >> 8;
	
   Return register may be configured in: ds_adc.s
*/
extern _ds_adc



/* ADC Hard-Coded Configuration Macros 

   Note: ds_adc.o must be linked after the C module
         that use below macros.
	
  * Public macro DS_ADC_OUT_PIN sets converter output pin. 
    Example:
  
  	#define public DS_ADC_OUT_PIN	PB2
	
    what is also the default.
    
  * Public macro DS_ADC_OUT_PORT sets port
    Example:
    
        #define public DS_ADC_OUT_PORT	PORTB
  
  * Macro DS_ADC_OFFSET_VOLTAGE is used to compensate constant
    error. Usually it equals 4. Example:
    
    	#define public DS_ADC_OFFSET_VOLTAGE	4
  
  * Macro DS_ADC_EXPIRE_PERIOD sets time-out period that
    breaks the conversion if voltage out of range is applied
    to the input. Default value is 0x3fff. Example:
    
        #define public DS_ADC_EXPIRE_PERIOD	0x3fff
	    
    
  Note: You must pass numbers to the following macros and not
        "other" macros unless ava version 0.3 or higher is installed.		
*/

#endif

